@@ -1,15 +1,16 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2019-2025, by Samuel Williams.
 # Copyright, 2020, by Bryan Powell.
+# Copyright, 2025, by William T. Nelson.
 
 require_relative "readable"
 
 module Protocol
 	module HTTP
 		module Body
-			# A body which buffers all it's contents.
+			# A body which buffers all its contents.
 			class Buffered < Readable
 				# Tries to wrap an object in a {Buffered} instance.
 				#
@@ -152,8 +153,10 @@ module Protocol
 				#
 				# @returns [String] a string representation of the buffered body.
 				def inspect
-					if @chunks
-						"\#<#{self.class} #{@chunks.size} chunks, #{self.length} bytes>"
+					if @chunks and @chunks.size > 0
+						"#<#{self.class} #{@index}/#{@chunks.size} chunks, #{self.length} bytes>"
+					else
+						"#<#{self.class} empty>"
 					end
 				end
 			end
